@@ -9,16 +9,12 @@ use crate::daemon::network::response_helper::*;
 /// Enqueue specific stashed tasks.
 pub fn enqueue(message: EnqueueMessage, state: &SharedState) -> Message {
     let mut state = state.lock().unwrap();
-    let (matching, mismatching) = {
-        let (matching, mismatching) = state.filter_tasks(
-            |task| matches!(task.status, TaskStatus::Stashed { .. } | TaskStatus::Locked),
-            Some(message.task_ids),
-        );
+    let filtered_tasks = state.filter_tasks(
+        |task| matches!(task.status, TaskStatus::Stashed { .. } | TaskStatus::Locked),
+        Some(message.task_ids),
+    );
 
-        (matching, mismatching)
-    };
-
-    for task_id in &matching {
+    for task_id in &filtered_tasks.matching_ids {
         // We just checked that they're there and the state is locked. It's safe to unwrap.
         let task = state.tasks.get_mut(task_id).expect("Task should be there.");
 
@@ -41,5 +37,5 @@ pub fn enqueue(message: EnqueueMessage, state: &SharedState) -> Message {
         String::from("Tasks are enqueued")
     };
 
-    compile_task_response(&text, matching, mismatching)
+    compile_task_response(&text, filtered_tasks)
 }
